@@ -10,11 +10,11 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our %TOOL;
 
@@ -68,7 +68,7 @@ sub rgb {
 
 sub rgba {
     my $rgb = [ map { $TOOL{scaled}( $_, 255 ) } ( $_[1], $_[2], $_[3] ) ];
-    return Hazy::Color->new( $rgb, $_[4] );
+    return Colouring::In->new( $rgb, $_[4] );
 }
 
 sub hsl {
@@ -102,7 +102,7 @@ sub new {
     # The end goal here, is to parse the arguments
     # into an integer triplet, such as `128, 255, 0`
     if ( ref $rgb eq 'ARRAY' ) {
-        scalar @$rgb == 4 and $a = shift @$rgb;
+        scalar @$rgb == 4 and $a = pop @$rgb;
         $self->{colour} = $rgb;
     }
     elsif ( ref \$rgb eq 'SCALAR' ) {
